==> haskell-data-dword-0.3.1.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-dword
version: 0.3.1.1
id: data-dword-0.3.1.1-8FidQK8SjvS1MBD4nE2pUO
key: data-dword-0.3.1.1-8FidQK8SjvS1MBD4nE2pUO
license: BSD3
copyright: 2011-2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-dword
synopsis: Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Data.DoubleWord Data.DoubleWord.TH
hidden-modules: Data.DoubleWord.Base
abi: 0910731ce58d2c1d9e5978a098e9d9ea
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/data-dword-0.3.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/data-dword-0.3.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/data-dword-0.3.1.1
hs-libraries: HSdata-dword-0.3.1.1-8FidQK8SjvS1MBD4nE2pUO
depends:
    base-4.9.0.0 data-bword-0.1.0.1-Jn2N6ji0zkfAlr9IANUzLx
    ghc-prim-0.5.0.0 hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    template-haskell-2.11.0.0
haddock-interfaces: /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html: /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-dword-0.3.1.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-dword
version: 0.3.1.1
id: data-dword-0.3.1.1-1MG8mNTIyavEWsvOfESjf4
key: data-dword-0.3.1.1-1MG8mNTIyavEWsvOfESjf4
license: BSD3
copyright: 2011-2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-dword
synopsis: Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Data.DoubleWord Data.DoubleWord.TH
hidden-modules: Data.DoubleWord.Base
abi: 35a61b6b316bc98e68f232847c66e51d
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/data-dword-0.3.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/data-dword-0.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/data-dword-0.3.1.1
hs-libraries: HSdata-dword-0.3.1.1-1MG8mNTIyavEWsvOfESjf4
depends:
    base-4.9.1.0 data-bword-0.1.0.1-H19AygIii9gIknda7gpa0a
    ghc-prim-0.5.0.0 hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    template-haskell-2.11.1.0
haddock-interfaces: /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html: /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
